<?php

declare(strict_types=1);

/**
 * This file is part of the EaseHtml package
 *
 * https://github.com/VitexSoftware/php-ease-html
 *
 * (c) Vítězslav Dvořák <http://vitexsoftware.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Test\Ease;

use Ease\Document;
use Ease\WebPage;

/**
 * Generated by PHPUnit_SkeletonGenerator on 2016-01-17 at 23:58:34.
 */
class WebPageTest extends DocumentTest
{
    public string $rendered = '<!DOCTYPE html><html lang="cs"><head><meta http-equiv="Content-Type" content="text/html; charset=utf-8" /><title></title></head><body></body></html>';
    protected $object;

    /**
     * Sets up the fixture, for example, opens a network connection.
     * This method is called before a test is executed.
     */
    protected function setUp(): void
    {
        $this->object = new WebPage();
        WebPage::singleton()->cascadeStyles = [];
        Document::singleton()->javaScripts = [];
    }

    /**
     * Tears down the fixture, for example, closes a network connection.
     * This method is called after a test is executed.
     */
    protected function tearDown(): void
    {
    }

    /**
     * @covers \Ease\WebPage::setTagID
     */
    public function testSetTagID(): void
    {
        $this->object->setTagID('test');
        $this->assertEquals('test', $this->object->getTagID());
    }

    /**
     * @covers \Ease\WebPage::addItem
     */
    public function testAddItem(): void
    {
        $this->object->emptyContents();
        $tester = new \Ease\Html\SpanTag();
        $this->object->addItem($tester);
        $this->assertEquals($this->object->getFirstPart(), $tester);
    }

    /**
     * @covers \Ease\WebPage::includeJavaScript
     */
    public function testIncludeJavaScript(): void
    {
        \Ease\WebPage::singleton()->javaScripts = [];
        $this->object->includeJavaScript('WebPage.js');
        $this->assertEquals(
            ['#WebPage.js'],
            \Ease\WebPage::singleton()->javaScripts,
        );
        \Ease\Document::singleton()->javaScripts = [];
    }

    /**
     * @covers \Ease\WebPage::addJavaScript
     */
    public function testAddJavaScript(): void
    {
        $this->assertEquals(
            0,
            $this->object->addJavaScript('alert("WebPageTest")'),
        );
        \Ease\Document::singleton()->javaScripts = [];
    }

    /**
     * @covers \Ease\WebPage::addToScriptsStack
     */
    public function testAddToScriptsStack(): void
    {
        $this->assertEquals(0, $this->object->addToScriptsStack('var test = 1;'));
        \Ease\Document::singleton()->javaScripts = [];
    }

    /**
     * @covers \Ease\WebPage::addCSS
     */
    public function testAddCSS(): void
    {
        $this->assertTrue($this->object->addCSS('border: 1px solid red'));
    }

    /**
     * @covers \Ease\WebPage::includeCss
     */
    public function testIncludeCss(): void
    {
        $this->assertTrue($this->object->includeCss('WebPage.css'));
        $this->assertTrue($this->object->includeCss('WebPage.css', '/js/'));
        \Ease\WebPage::singleton()->cascadeStyles = [];
    }

    /**
     * @covers \Ease\WebPage::getStatusMessagesBlock
     */
    public function testGetStatusMessagesBlock(): void
    {
        \Ease\Shared::logger()->cleanMessages();
        $this->object->addStatusMessage(
            'success Status message for testGetStatusMessagesAsHtml',
            'success',
        );
        $this->object->addStatusMessage(
            'warning Status message for testGetStatusMessagesAsHtml',
            'warning',
        );
        $this->object->addStatusMessage(
            'error Status message for testGetStatusMessagesAsHtml',
            'error',
        );
        $this->assertEquals(
            '<div><div style="color: #2C5F23;" data-caller="Ease\WebPage">🌼&nbsp;success Status message for testGetStatusMessagesAsHtml</div><div style="color: #AB250E;" data-caller="Ease\WebPage">⚠&nbsp;warning Status message for testGetStatusMessagesAsHtml</div><div style="color: red;" data-caller="Ease\WebPage">💀&nbsp;error Status message for testGetStatusMessagesAsHtml</div></div>',
            $this->object->getStatusMessagesBlock()->__toString(),
        );
    }

    /**
     * @covers \Ease\WebPage::draw
     *
     * @param null|mixed $whatWant
     */
    public function testDraw($whatWant = null): void
    {
        $this->object->emptyContents();
        \Ease\WebPage::singleton()->javaScripts = [];
        \Ease\WebPage::singleton()->cascadeStyles = [];
        parent::testDraw($whatWant);
    }

    /**
     * @covers \Ease\WebPage::finalizeRegistred
     */
    public function testFinalizeRegistred(): void
    {
        $this->object->finalizeRegistred();
        $this->assertEmpty(WebPage::$allItems);
    }

    /**
     * @covers \Ease\WebPage::setPageTitle
     *
     * @todo   Implement testSetPageTitle().
     */
    public function testSetPageTitle(): void
    {
        // Remove the following lines when you implement this test.
        $this->markTestIncomplete(
            'This test has not been implemented yet.',
        );
    }

    /**
     * @covers \Ease\WebPage::getItemsCount
     */
    public function testGetItemsCount(): void
    {
        $this->assertEquals(0, $this->object->getItemsCount());
    }

    /**
     * @covers \Ease\WebPage::drawIfNotDrawn
     *
     * @param mixed $canBeEmpty
     */
    public function testDrawIfNotDrawn($canBeEmpty = false): void
    {
        \Ease\WebPage::clearJavaScriptsCache();
        parent::testDrawIfNotDrawn($canBeEmpty);
    }
}
